import NextAuth, { NextAuthOptions } from "next-auth";
import CognitoProvider from "next-auth/providers/cognito"

import {
  authJwtSecret,
  providerClientId,
  providerClientSecret,
  providerIssuer,
} from "../../../utils/env";

// TODO: handle refresh token
export const authOptions: NextAuthOptions = {
  debug: true,
  session: { strategy: "jwt" },
  secret: authJwtSecret,
  providers: [
    CognitoProvider({
      clientId: providerClientId,
      clientSecret: providerClientSecret,
      issuer: providerIssuer,
      idToken: true,
      checks: 'nonce',
    }),
  ],
  callbacks: {
    // checks whether user is allowed to sign in
    async signIn({ account }) {
      return true;
    },

    async jwt({ token, account, profile }) {
        const prof = (profile as any);
        let did: string | undefined;
        if(prof?.name) {
          did = JSON.parse(decodeURIComponent(prof?.name))[2].did;
        }

        const email = prof?.email;

        return {
        ...token,
        ...(email && { email }),
        ...(did && { did: did.split(";")[0] }),
        ...(account?.access_token && { accessToken: account?.access_token }),
        ...(account?.id_token && { idToken: account?.id_token }),
        ...(profile?.sub && { userId: profile?.sub }),
        };
    },

    async session({ session, token }) {
        return {
        ...session,
        ...session.user,
        ...(token.did && { did: token.did.split(";")[0] }),
        ...(token.email && { email: token.email }),
        ...(token.userId && { userId: token.userId }),
        ...(token.accessToken && { accessToken: token.accessToken }),
        ...(token.idToken && { idToken: token.idToken }),
        };
    },
  } 
};

export default NextAuth(authOptions);
